#!/bin/sh
#############################################################################
# (C) COPYRIGHT Tivoli Systems, IBM Corp. 1997, 1999
# All Rights Reserved
# Licensed Material - Property of IBM
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#############################################################################
#
# Name        : src/Monitor/Scripts/dps_integrity_monitor.sh
#
# Component   : notes
#
# Abstract    : Checks the status of the probe station
#
#
# Description : Checks the status of the probe station
#		Changes icon state if either DPS components are down or
#               if a probe is consistently in error.
#
# Parameter(s):
#
# Called By   : 
#
# Other script(s)/program(s) it executes: dps_integrity.sh
#
# Adjustments :
#
# Defect  ID   Change Description
# ------  ---  --------------------------------------------------------------
# XXXXX   CRM  Created
#
#############################################################################

# Source the common shell script
. "$LCF_BINDIR/../TME/DominoManager2/DominoPerformanceStation/dps_common.sh"




# Req'd to source the RAS script functions
dps_setup_env

cd "$LCF_BINDIR"

# Set the tools dir if it's not defined
if [ -z "$APPLSVCS_DIR" ] ; then
    APPLSVCS_DIR="$LCF_DATDIR/LCFNEW/Tmw2k/bin"
fi

# Look elsewhere for the wasgetattr program
if [ ! -f "$APPLSVCS_DIR"/wasgetattr.exe ] ; then
    APPLSVCS_DIR="$LCF_BINDIR/../TME/APPLSVCS"
fi

# Get the AMS OID and key so that we can make the AMS CLI calls
# ams_instance_oid=`cat "$GL_DPS_HOME/dps.key" | awk '{ print $2 }'`
# ams_instance_key=`cat "$GL_DPS_HOME/dps.key" | awk -F\" '{ print $2 }'`
ams_instance_oid=$1
ams_instance_key=$2

# Now get cached attributes log_id and ctr_state
log_id=`"$APPLSVCS_DIR"/wasgetattr -a ctr_log_id -o $ams_instance_oid -k $ams_instance_key`
ctr_state=`"$APPLSVCS_DIR"/wasgetattr -a ctr_state -o $ams_instance_oid -k $ams_instance_key`

log_id=`TMDRAS_ENTERSCRIPT $log_id DominoManager2 DominoPerformanceStation DPSIntegrity "$0"`

TMDRAS_DUMPINFO $log_id "dps_integrity_monitor: AMS_INSTANCE_OID = $ams_instance_oid"
TMDRAS_DUMPINFO $log_id "dps_integrity_monitor: AMS_INSTANCE_KEY = $ams_instance_key"
TMDRAS_DUMPINFO $log_id "dps_integrity_monitor: ctr_state = $ctr_state"

# Run the integrity check utility
"$LCF_BINDIR"/../TME/DominoManager2/DominoPerformanceStation/dps_integrity.sh $log_id unused $ctr_state > /dev/null
return_code=$?
message=DANIEL
if [ $return_code -eq `dps_get_message_id dps_cli_success` ] ; then
    state=normal
    if [ $ctr_state -eq `dps_get_message_id dps_cli_up` ] ; then
        #echo Up
	message=Up
    else
        #echo Down
	message=Down
    fi
else
    state=warning
    #echo Recurring error
    message="Recurring error"
fi

TMDRAS_DUMPINFO $log_id "dps_integrity_monitor: message = $message"
TMDRAS_DUMPINFO $log_id "dps_integrity_monitor: command = wassetstate -o $ams_instance_oid -k \"$ams_instance_key\" -s $state"
output=`"$LCF_TOOLSDIR"/wassetstate -o $ams_instance_oid -k "$ams_instance_key" -s $state 2>&1`
TMDRAS_DUMPINFO $log_id "dps_integrity_monitor: Output: $output"
#echo "$output" | TMDRAS_DUMPINFO $log_id
TMDRAS_DUMPINFO $log_id "dps_integrity_monitor: return_code = $?"
TMDRAS_DUMPINFO $log_id "dps_integrity_monitor: about to exit"
TMDRAS_EXITSCRIPT $log_id DominoManager2 DominoPerformanceStation DPSIntegrity "$0"
echo $message
exit 0
